@@ -121,19 +121,24 @@ def bsavefig(d, s):
 
 def mch_plot_bg(d, **kwargs):
     """Plot background vs channel for DA, D and A photons."""
-    plot(r_[1:d.nch+1], [b.mean()*1e-3 for b in d.bg], lw=2, color=blue,
+    bg = d.bg_from(Ph_sel('all'))
+    bg_dd = d.bg_from(Ph_sel(Dex='Dem'))
+    bg_ad = d.bg_from(Ph_sel(Dex='Aem'))
+    plot(r_[1:d.nch+1], [b.mean()*1e-3 for b in bg], lw=2, color=blue,
          label=' T', **kwargs)
-    plot(r_[1:d.nch+1], [b.mean()*1e-3 for b in d.bg_dd], color=green, lw=2,
+    plot(r_[1:d.nch+1], [b.mean()*1e-3 for b in bg_dd], color=green, lw=2,
          label=' D', **kwargs)
-    plot(r_[1:d.nch+1], [b.mean()*1e-3 for b in d.bg_ad], color=red, lw=2,
+    plot(r_[1:d.nch+1], [b.mean()*1e-3 for b in bg_ad], color=red, lw=2,
          label=' A', **kwargs)
     xlabel("CH"); ylabel("kcps"); grid(True); legend(loc='best')
     title(d.name)
 
 def mch_plot_bg_ratio(d):
     """Plot ratio of A over D background vs channel."""
+    bg_dd = d.bg_from(Ph_sel(Dex='Dem'))
+    bg_ad = d.bg_from(Ph_sel(Dex='Aem'))
     plot(r_[1:d.nch+1],
-         [ba.mean()/bd.mean() for bd, ba in zip(d.bg_dd, d.bg_ad)],
+         [ba.mean()/bd.mean() for bd, ba in zip(bg_dd, bg_ad)],
          color=green, lw=2, label='A/D')
     xlabel("CH"); ylabel("BG Ratio A/D"); grid(True)
     title("BG Ratio A/D "+d.name)
@@ -668,25 +673,31 @@ def timetrace_fret_scatter(d, i=0, gamma=1., **kwargs):
     plt.scatter(b.start*d.clk_p, d.E[i], **style_kwargs)
     xlabel('Time (s)'); ylabel('E')
 
+
 def timetrace_bg(d, i=0, nolegend=False, ncol=2, plot_style={}):
     """Timetrace of background rates."""
-    t = arange(d.bg[i].size)*d.bg_time_s
+    bg = d.bg_from(Ph_sel('all'))
+    bg_dd = d.bg_from(Ph_sel(Dex='Dem'))
+    bg_ad = d.bg_from(Ph_sel(Dex='Aem'))
+    t = arange(bg[i].size) * d.bg_time_s
     plot_style_ = dict(linewidth=2, marker='o', markersize=6)
     plot_style_.update(_normalize_kwargs(plot_style, kind='line2d'))
-    plot(t, 1e-3*d.bg[i], color='k', label="T: %d cps" % d.rate_m[i],
-         **plot_style_)
-    plot(t, 1e-3*d.bg_dd[i], color=green, label="DD: %d cps" % d.rate_dd[i],
-         **plot_style_)
-    plot(t, 1e-3*d.bg_ad[i], color=red, label="AD: %d cps" % d.rate_ad[i],
-         **plot_style_)
+    label = "T: %d cps" % d.bg_mean[Ph_sel('all')][i]
+    plot(t, 1e-3 * bg[i], color='k', label=label, **plot_style_)
+    label = "DD: %d cps" % d.bg_mean[Ph_sel(Dex='Dem')][i]
+    plot(t, 1e-3 * bg_dd[i], color=green, label=label, **plot_style_)
+    label = "AD: %d cps" % d.bg_mean[Ph_sel(Dex='Aem')][i]
+    plot(t, 1e-3 * bg_ad[i], color=red, label=label, **plot_style_)
     if d.ALEX:
-        plot(t, 1e-3*d.bg_aa[i], label="AA: %d cps" % d.rate_aa[i],
-             color=purple, **plot_style_)
+        bg_aa = d.bg_from(Ph_sel(Aex='Aem'))
+        label = "AA: %d cps" % d.bg_mean[Ph_sel(Aex='Aem')][i]
+        plot(t, 1e-3 * bg_aa[i], label=label, color=purple, **plot_style_)
     if not nolegend:
         legend(loc='best', frameon=False, ncol=ncol)
     xlabel("Time (s)"); ylabel("BG rate (kcps)"); grid(True)
     plt.ylim(ymin=0)
 
+
 def timetrace_b_rate(d, i=0):
     """Timetrace of bursts-per-second in each period."""
     t = arange(d.bg[i].size)*d.bg_time_s
@@ -1058,7 +1069,7 @@ def hist_burst_data(
         bext.bursts_fitter(d, burst_data=data_name, weights=weights,
                            gamma=gamma, add_naa=add_naa)
 
-    # fitter_name is only a attribute of Data, not a key in the dictionary
+    # fitter_name is only an attribute of Data, not a key in the dictionary
     fitter = getattr(d, fitter_name)
     fitter.histogram(binwidth=binwidth, bins=bins, verbose=verbose)
     if pdf:
@@ -1100,13 +1111,13 @@ def hist_burst_data(
                                                    kind='line2d'))
         fit_res = fitter.fit_res[i]
         x = fitter.x_axis
-        y = scale*fit_res.model.eval(x=x, **fit_res.values)
+        y = fit_res.model.eval(x=x, **fit_res.values)
         xx, yy = (y, x) if vertical else (x, y)
         ax.plot(xx, yy, **model_plot_style_)
-        if  fit_res.model.components is not None:
+        if fit_res.model.components is not None:
             for component in fit_res.model.components:
                 model_plot_style_.update(ls='--', label='Model component')
-                y = scale*component.eval(x=x, **fit_res.values)
+                y = component.eval(x=x, **fit_res.values)
                 xx, yy = (y, x) if vertical else (x, y)
                 ax.plot(xx, yy, **model_plot_style_)
         if show_model_peaks:
@@ -1120,7 +1131,7 @@ def hist_burst_data(
                                label='KDE')
         kde_plot_style_.update(_normalize_kwargs(kde_plot_style,
                                                  kind='line2d'))
-        y = scale*fitter.kde[i](x)
+        y = scale * fitter.kde[i](x)
         xx, yy = (y, x) if vertical else (x, y)
         ax.plot(xx, yy, **kde_plot_style_)
     if show_kde_peak:
@@ -1321,28 +1332,65 @@ def get_ES_range():
         print('E1={E1:.3}, E2={E2:.3}, S1={S1:.3}, S2={S2:.3}'.format(**sel))
     return sel
 
-def hist_bg_single(d, i=0, period=0, binwidth=1e-4, bins=None, tmax=0.01,
-                   ph_sel=Ph_sel('all'), show_fit=True, yscale='log',
-                   manual_rate=None, manual_tau_th=500,
-                   xscale='linear', plot_style=None, fit_style=None):
-    """Plot histogram of photon interval for a single photon streams.
 
-    Optionally plots the fitted background.
+def hist_interphoton_single(d, i=0, binwidth=1e-4, tmax=None, bins=None,
+                            ph_sel=Ph_sel('all'), period=None,
+                            yscale='log', xscale='linear', xunit='ms',
+                            plot_style=None):
+    """Plot histogram of interphoton delays for a single photon streams.
+
+    Arguments:
+        d (Data object): the input data.
+        i (int): the channel for which the plot must be done. Default is 0.
+            For single-spot data the only valid value is 0.
+        binwidth (float): histogram bin width in seconds.
+        tmax (float or None): max timestamp delay in the histogram (seconds).
+            If None (default), uses the the max timestamp delay in the stream.
+            If not None, the plotted histogram may be further trimmed to
+            the smallest delay with counts > 0 if this delay happens to be
+            smaller than `tmax`.
+        bins (array or None): specifies the bin edged (in seconds). When
+            `bins` is not None then the arguments `binwidth` and `tmax`
+            are ignored. When `bins` is None, the bin edges are computed
+            from the `binwidth` and `tmax` arguments.
+        ph_sel (Ph_sel object): photon stream for which plotting the histogram
+        period (int): the background period to use for plotting the histogram.
+            The background period is a time-slice of the measurement from which
+            timestamps are taken. If `period` is None (default) the
+            time-windows is the full measurement.
+        yscale (string): scale for the y-axis. Valid values include 'log' and
+            'linear'. Default 'log'.
+        xscale (string): scale for the x-axis. Valid values include 'log' and
+            'linear'. Default 'linear'.
+        xunit (string): unit used for the x-axis. Valid values are 's', 'ms',
+            'us', 'ns'. Default 'ms'.
+        plot_style (dict): keyword arguments to be passed to matplotlib's
+            `plot` function. Used to customize the plot style.
     """
+    unit_dict = {'s': 1, 'ms': 1e3, 'us': 1e6, 'ns': 1e9}
+    assert xunit in unit_dict
+    scalex = unit_dict[xunit]
 
-    # If `bins` is not passed or is a scalar create the `bins` array
+    # Compute interphoton delays
+    if period is None:
+        ph_times = d.get_ph_times(ich=i, ph_sel=ph_sel)
+    else:
+        ph_times = d.get_ph_times_period(ich=i, period=period, ph_sel=ph_sel)
+    delta_ph_t = np.diff(ph_times) * d.clk_p
+    if tmax is None:
+        tmax = delta_ph_t.max()
+
+    # Compute bin edges if not passed in
     if bins is None:
-        bins = np.arange(0, tmax + binwidth, binwidth)
-    elif np.size(bins) == 1:
-        warnings.warn('`bins` is a scalar, `tmax` will be ignored.')
-        bins = np.arange(0, bins*binwidth, binwidth)
-    t_ax = bins[:-1] + 0.5*binwidth
+        # Shift by half clk_p to avoid "beatings" in the distribution
+        # due to floating point inaccuracies.
+        bins = np.arange(0, tmax + binwidth, binwidth) - 0.5 * d.clk_p
+    else:
+        warnings.warn('Using `bins` and ignoring `tmax` and `binwidth`.')
+    t_ax = bins[:-1] + 0.5 * binwidth
 
-    # Compute histograms
-    ph_times_period = d.get_ph_times_period(ich=i, period=period,
-                                            ph_sel=ph_sel)
-    delta_ph_t_period = np.diff(ph_times_period)*d.clk_p
-    counts, _ = np.histogram(delta_ph_t_period, bins=bins)
+    # Compute interphoton histogram
+    counts, _ = np.histogram(delta_ph_t, bins=bins)
 
     # Max index with counts > 0
     n_trim = np.trim_zeros(counts).size + 1
@@ -1353,51 +1401,146 @@ def hist_bg_single(d, i=0, period=0, binwidth=1e-4, bins=None, tmax=0.01,
         plot_style_['color'] = _ph_sel_color_dict[ph_sel]
         plot_style_['label'] = _ph_sel_label_dict[ph_sel]
     plot_style_.update(_normalize_kwargs(plot_style, kind='line2d'))
-    plot(t_ax[:n_trim]*1e3, counts[:n_trim], **plot_style_)
+    plot(t_ax[:n_trim] * scalex, counts[:n_trim], **plot_style_)
+
+    if yscale == 'log':
+        gca().set_yscale(yscale)
+        plt.ylim(1)
+        _plot_status['hist_interphoton_single'] = {'autoscale': False}
+    if xscale == 'log':
+        gca().set_xscale(yscale)
+        plt.xlim(0.5 * binwidth)
+        _plot_status['hist_interphoton_single'] = {'autoscale': False}
+    plt.xlabel('Inter-photon delays (%s)' % xunit.replace('us', 'μs'))
+    plt.ylabel('# Delays')
+    # Return interal variables so that other functions can extend the plot
+    return dict(counts=counts, n_trim=n_trim, plot_style_=plot_style_,
+                t_ax=t_ax, scalex=scalex)
+
+
+def hist_interphoton(d, i=0, binwidth=1e-4, tmax=None, bins=None, period=None,
+                     yscale='log', xscale='linear', xunit='ms', plot_style=None,
+                     show_da=False, legend=True):
+    """Plot histogram of photon interval for different photon streams.
+
+    Arguments:
+        d (Data object): the input data.
+        i (int): the channel for which the plot must be done. Default is 0.
+            For single-spot data the only valid value is 0.
+        binwidth (float): histogram bin width in seconds.
+        tmax (float or None): max timestamp delay in the histogram (seconds).
+            If None (default), uses the the max timestamp delay in the stream.
+            If not None, the plotted histogram may be further trimmed to
+            the smallest delay with counts > 0 if this delay happens to be
+            smaller than `tmax`.
+        bins (array or None): specifies the bin edged (in seconds). When
+            `bins` is not None then the arguments `binwidth` and `tmax`
+            are ignored. When `bins` is None, the bin edges are computed
+            from the `binwidth` and `tmax` arguments.
+        period (int): the background period to use for plotting the histogram.
+            The background period is a time-slice of the measurement from which
+            timestamps are taken. If `period` is None (default) the
+            time-windows is the full measurement.
+        yscale (string): scale for the y-axis. Valid values include 'log' and
+            'linear'. Default 'log'.
+        xscale (string): scale for the x-axis. Valid values include 'log' and
+            'linear'. Default 'linear'.
+        xunit (string): unit used for the x-axis. Valid values are 's', 'ms',
+            'us', 'ns'. Default 'ms'.
+        plot_style (dict): keyword arguments to be passed to matplotlib's
+            `plot` function. Used to customize the plot style.
+        show_da (bool): If False (default) do not plot the AexDem photon stream.
+            Ignored when the measurement is not ALEX.
+        legend (bool): If True (default) plot a legend.
+    """
+    # Plot multiple timetraces
+    ph_sel_list = [Ph_sel('all'), Ph_sel(Dex='Dem'), Ph_sel(Dex='Aem')]
+    if d.ALEX:
+        ph_sel_list.append(Ph_sel(Aex='Aem'))
+        if show_da:
+            ph_sel_list.append(Ph_sel(Aex='Dem'))
+
+    for ix, ph_sel in enumerate(ph_sel_list):
+        if not bl.mask_empty(d.get_ph_mask(i, ph_sel=ph_sel)):
+            hist_interphoton_single(d, i=i, binwidth=binwidth, tmax=tmax,
+                                    bins=bins, period=period, ph_sel=ph_sel,
+                                    yscale=yscale, xscale=xscale, xunit=xunit,
+                                    plot_style=plot_style)
+    if legend:
+        plt.legend(loc='best', fancybox=True)
+
+    if yscale == 'log' or xscale == 'log':
+        _plot_status['hist_interphoton'] = {'autoscale': False}
+
+
+def hist_bg_single(d, i=0, binwidth=1e-4, tmax=0.01, bins=None,
+                   ph_sel=Ph_sel('all'), period=0,
+                   yscale='log', xscale='linear', xunit='ms', plot_style=None,
+                   show_fit=True, fit_style=None, manual_rate=None):
+    """Plot histogram of photon interval for a single photon streams.
+
+    Optionally plots the fitted background as an exponential curve.
+    Most arguments are described in :func:`hist_interphoton_single`.
+    In the following we document only the additional arguments.
+
+    Arguments:
+        show_fit (bool): If True shows the fitted background rate as an
+            exponential distribution.
+        manual_rate (float or None): When not None use this value as background
+            rate (ignoring the value saved in Data).
+        fit_style (dict): arguments passed to matplotlib's `plot` for
+            for plotting the exponential curve.
+
+    For a description of all the other arguments see
+    :func:`hist_interphoton_single`.
+    """
+    hist = hist_interphoton_single(d, i=i, binwidth=binwidth, tmax=tmax,
+                                   bins=bins, ph_sel=ph_sel, period=period,
+                                   yscale=yscale, xscale=xscale, xunit=xunit,
+                                   plot_style=None)
 
     if show_fit or manual_rate is not None:
         # Compute the fit function
         if manual_rate is not None:
             bg_rate = manual_rate
-            tau_th = manual_tau_th*1e-6
         else:
             bg_rate = d.bg_from(ph_sel)[i][period]
-            tau_th = d.bg_th_us[ph_sel][i]*1e-6
+        tau_th = bg_rate * 1e-6
 
-        i_tau_th = np.searchsorted(t_ax, tau_th)
-        counts_integral = counts[i_tau_th:].sum()
-        y_fit = np.exp(- t_ax * bg_rate)
-        y_fit *= counts_integral/y_fit[i_tau_th:].sum()
+        i_tau_th = np.searchsorted(hist['t_ax'], tau_th)
+        counts_integral = hist['counts'][i_tau_th:].sum()
+        y_fit = np.exp(- hist['t_ax'] * bg_rate)
+        y_fit *= counts_integral / y_fit[i_tau_th:].sum()
 
         # Plot
-        fit_style_ = dict(plot_style_)
+        fit_style_ = dict(hist['plot_style_'])
         fit_style_.update(linestyle='-', marker='', label='auto')
         fit_style_.update(_normalize_kwargs(fit_style, kind='line2d'))
         if fit_style_['label'] is 'auto':
-            plt_label = plot_style_.get('label', None)
+            plt_label = hist['plot_style_'].get('label', None)
             label = str(ph_sel) if plt_label is None else plt_label
-            fit_style_['label'] = '%s, %.2f kcps' % (label,
-                                                     bg_rate*1e-3)
-        plot(t_ax[:n_trim]*1e3, y_fit[:n_trim], **fit_style_)
-
-    if yscale == 'log':
-        gca().set_yscale(yscale)
-        plt.ylim(1)
-        _plot_status['hist_bg_single'] = {'autoscale': False}
-    if xscale == 'log':
-        gca().set_xscale(yscale)
-        plt.xlim(0.5*binwidth)
-        _plot_status['hist_bg_single'] = {'autoscale': False}
-    plt.xlabel('Inter-photon delay (ms)')
-    plt.ylabel('# Delays')
+            fit_style_['label'] = '%s, %.2f kcps' % (label, bg_rate * 1e-3)
+        n_trim = hist['n_trim']
+        plot(hist['t_ax'][:n_trim] * hist['scalex'], y_fit[:n_trim],
+             **fit_style_)
 
 
-def hist_bg(d, i=0, period=0, binwidth=1e-4, bins=None, tmax=0.01,
-            show_da=False, show_fit=True, yscale='log', xscale='linear',
-            plot_style=None, fit_style=None, legend=True):
+def hist_bg(d, i=0, binwidth=1e-4, tmax=0.01, bins=None, period=0,
+            yscale='log', xscale='linear', xunit='ms', plot_style=None,
+            show_da=False, legend=True, show_fit=True, fit_style=None):
     """Plot histogram of photon interval for different photon streams.
 
     Optionally plots the fitted background.
+    Most arguments are described in :func:`hist_interphoton`.
+    In the following we document only the additional arguments.
+
+    Arguments:
+        show_fit (bool): If True shows the fitted background rate as an
+            exponential distribution.
+        fit_style (dict): arguments passed to matplotlib's `plot` for
+            for plotting the exponential curve.
+
+    For a description of all the other arguments see :func:`hist_interphoton`.
     """
     # Plot multiple timetraces
     ph_sel_list = [Ph_sel('all'), Ph_sel(Dex='Dem'), Ph_sel(Dex='Aem')]
@@ -1409,7 +1552,7 @@ def hist_bg(d, i=0, period=0, binwidth=1e-4, bins=None, tmax=0.01,
     for ix, ph_sel in enumerate(ph_sel_list):
         if not bl.mask_empty(d.get_ph_mask(i, ph_sel=ph_sel)):
             hist_bg_single(d, i=i, period=period, binwidth=binwidth,
-                           bins=bins, tmax=tmax, ph_sel=ph_sel,
+                           bins=bins, tmax=tmax, ph_sel=ph_sel, xunit=xunit,
                            show_fit=show_fit, yscale=yscale, xscale=xscale,
                            plot_style=plot_style, fit_style=fit_style)
     if legend:
@@ -1418,6 +1561,7 @@ def hist_bg(d, i=0, period=0, binwidth=1e-4, bins=None, tmax=0.01,
     if yscale == 'log' or xscale == 'log':
         _plot_status['hist_bg'] = {'autoscale': False}
 
+
 def hist_ph_delays(
         d, i=0, time_min_s=0, time_max_s=30, bin_width_us=10, mask=None,
         yscale='log', hfit_bin_ms=1, efit_tail_min_us=1000, **kwargs):
@@ -1613,7 +1757,7 @@ def scatter_width_size(d, i=0):
     t_ms = arange(0, 50)
     plot(t_ms, ((d.m)/(d.T[i]))*t_ms*1e-3, '--', lw=2, color='k',
          label='Slope = m/T = min. rate = %1.0f cps' % (d.m/d.T[i]))
-    plot(t_ms, d.rate_m[i]*t_ms*1e-3, '--', lw=2, color=red,
+    plot(t_ms, d.bg_mean[Ph_sel('all')][i]*t_ms*1e-3, '--', lw=2, color=red,
          label='Noise rate: BG*t')
     xlabel('Burst width (ms)'); ylabel('Burst size (# ph.)')
     plt.xlim(0, 10); plt.ylim(0, 300)
@@ -1694,32 +1838,32 @@ def scatter_alex(d, i=0, **kwargs):
 #  High-level plot wrappers
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-def dplot_48ch(d, func, sharex=True, sharey=True,
+def dplot_48ch(d, func, sharex=True, sharey=True, layout='horiz',
                pgrid=True, figsize=None, AX=None, nosuptitle=False,
-               scale=True, ich=None, **kwargs):
+               scale=True, **kwargs):
     """Plot wrapper for 48-spot measurements. Use `dplot` instead."""
+    msg = "Wrong layout '%s'. Valid values: 'horiz', 'vert', '6x4'."
+    assert (layout.startswith('vert') or layout.startswith('horiz') or
+            layout == '8x6'), (msg % layout)
     global gui_status
-    if ich is None:
-        iter_ch = range(d.nch)
-        if d.nch == 48:
-            top_adjust = 0.95
-            ax_ny, ax_nx = 6, 8
-            if figsize is None:
-                figsize = (20, 16)
-        elif d.nch == 8:
-            top_adjust = 0.93
-            ax_ny, ax_nx = 4, 2
-            if figsize is None:
-                figsize = (12, 9)
-    else:
-        top_adjust = 0.9
-        iter_ch = [ich]
-        ax_ny, ax_nx = 1, 1
+    iter_ch = range(48)
+    top_adjust = 0.95
+    if layout == '8x6':
+        nrows, ncols = 6, 8
         if figsize is None:
-            figsize = (8, 5)
+            figsize = (20, 16)
+    else:
+        nrows, ncols = 4, 12
+        if layout.startswith('vert'):
+            nrows, ncols = ncols, nrows
+            iter_ch = np.arange(48).reshape(4, 12).T.ravel()
+        if figsize is None:
+            figsize = (20, 7)
+            if layout.startswith('vert'):
+                figsize = figsize[1], figsize[0]
 
     if AX is None:
-        fig, AX = plt.subplots(ax_ny, ax_nx, figsize=figsize, sharex=sharex,
+        fig, AX = plt.subplots(nrows, ncols, figsize=figsize, sharex=sharex,
                                sharey=sharey, squeeze=False)
         fig.subplots_adjust(left=0.08, right=0.96, top=top_adjust,
                             bottom=0.07, wspace=0.05)
@@ -1733,24 +1877,29 @@ def dplot_48ch(d, func, sharex=True, sharey=True,
         ax = AX.ravel()[i]
         if i == 0 and not nosuptitle:
             fig.suptitle(d.status())
-        s = u'[%d]' % (ich+1)
-        if 'rate_m' in d: s += (' BG=%.1fk' % (d.rate_m[ich]*1e-3))
-        if b is not None: s += (', #bu=%d' %  b.num_bursts)
-        ax.set_title(s, fontsize=12)
+        s = u'[%d]' % (ich + 1)
+        if 'bg_mean' in d:
+            s += (' BG=%.1fk' % (d.bg_mean[Ph_sel('all')][ich] * 1e-3))
+        if b is not None:
+            s += (', #bu=%d' % b.num_bursts)
+        ax.set_title(s)
         ax.grid(pgrid)
         plt.sca(ax)
         gui_status['first_plot_in_figure'] = (i == 0)
         func(d, ich, **kwargs)
+        if ax.legend_ is not None:
+            ax.legend_.remove()
     [a.set_xlabel('') for a in AX[:-1, :].ravel()]
     [a.set_ylabel('') for a in AX[:, 1:].ravel()]
     if sharex:
         plt.setp([a.get_xticklabels() for a in AX[:-1, :].ravel()],
                  visible=False)
         [a.set_xlabel('') for a in AX[:-1, :].ravel()]
-        if not old_ax: fig.subplots_adjust(hspace=0.15)
+        if not old_ax:
+            fig.subplots_adjust(hspace=0.15)
     if sharey:
         if AX.shape[1] > 1:
-             plt.setp([a.get_yticklabels() for a in AX[:, 1]], visible=False)
+            plt.setp([a.get_yticklabels() for a in AX[:, 1]], visible=False)
         fig.subplots_adjust(wspace=0.08)
 
         func_allows_autoscale = True
@@ -1760,6 +1909,7 @@ def dplot_48ch(d, func, sharex=True, sharey=True,
             ax.autoscale(enable=True, axis='y')
     return AX
 
+
 def dplot_8ch(d, func, sharex=True, sharey=True,
               pgrid=True, figsize=(12, 9), nosuptitle=False, AX=None,
               scale=True, **kwargs):
@@ -1784,8 +1934,10 @@ def dplot_8ch(d, func, sharex=True, sharey=True,
         if i == 0 and not nosuptitle:
             fig.suptitle(d.status())
         s = u'[%d]' % (i+1)
-        if 'rate_m' in d: s += (' BG=%.1fk' % (d.rate_m[i]*1e-3))
-        if 'T' in d: s += (u', T=%dμs' % (d.T[i]*1e6))
+        if 'bg_mean' in d:
+            s += (' BG=%.1fk' % (d.bg_mean[Ph_sel('all')][i]*1e-3))
+        if 'T' in d:
+            s += (u', T=%dμs' % (d.T[i]*1e6))
         if b is not None: s += (', #bu=%d' %  b.num_bursts)
         ax.set_title(s, fontsize=12)
         ax.grid(pgrid)
@@ -1811,6 +1963,7 @@ def dplot_8ch(d, func, sharex=True, sharey=True,
             ax.autoscale(enable=True, axis='y')
     return AX
 
+
 def dplot_1ch(d, func, pgrid=True, ax=None,
               figsize=(9, 4.5), fignum=None, nosuptitle=False, **kwargs):
     """Plot wrapper for single-spot measurements. Use `dplot` instead."""
@@ -1821,10 +1974,14 @@ def dplot_1ch(d, func, pgrid=True, ax=None,
     else:
         fig = ax.figure
     s = d.name
-    if 'rate_m' in d: s += (' BG=%.1fk' % (d.rate_m[0]*1e-3))
-    if 'T' in d: s += (u', T=%dμs' % (d.T[0]*1e6))
-    if 'mburst' in d: s += (', #bu=%d' %  d.num_bursts[0])
-    if not nosuptitle: ax.set_title(s, fontsize=12)
+    if 'bg_mean' in d:
+        s += (' BG=%.1fk' % (d.bg_mean[Ph_sel('all')][0] * 1e-3))
+    if 'T' in d:
+        s += (u', T=%dμs' % (d.T[0] * 1e6))
+    if 'mburst' in d:
+        s += (', #bu=%d' % d.num_bursts[0])
+    if not nosuptitle:
+        ax.set_title(s, fontsize=12)
     ax.grid(pgrid)
     plt.sca(ax)
     gui_status['first_plot_in_figure'] = True
