@@ -15,12 +15,15 @@ from builtins import range, zip
 from collections import namedtuple
 import pytest
 import numpy as np
+import matplotlib
+matplotlib.use('Agg')
 
-from fretbursts import loader
-from fretbursts import select_bursts
 import fretbursts.background as bg
 import fretbursts.burstlib as bl
 import fretbursts.burstlib_ext as bext
+import fretbursts.burst_plot as bplt
+from fretbursts import loader
+from fretbursts import select_bursts
 from fretbursts.ph_sel import Ph_sel
 from fretbursts.phtools import phrates
 
@@ -137,64 +140,75 @@ def test_time_min_max():
 def test_time_min_max_multispot(data_8ch):
     """Test time_min and time_max for multi-spot data."""
     d = data_8ch
-    assert d.time_max == max(t[-1] for t in d.ph_times_m)*d.clk_p
-    assert d.time_min == min(t[0] for t in d.ph_times_m)*d.clk_p
+    assert d.time_max == max(t[-1] for t in d.ph_times_m) * d.clk_p
+    assert d.time_min == min(t[0] for t in d.ph_times_m) * d.clk_p
+
 
 def test_bg_calc(data):
     """Smoke test bg_calc() and test deletion of bg fields.
     """
     data.calc_bg(bg.exp_fit, time_s=30, tail_min_us=300)
+    assert 'bg_auto_th_us0' not in data
+    assert 'bg_auto_F_bg' not in data
+    assert 'bg_th_us_user' in data
+
     data.calc_bg(bg.exp_fit, time_s=30, tail_min_us='auto', F_bg=1.7)
     assert 'bg_auto_th_us0' in data
     assert 'bg_auto_F_bg' in data
     assert 'bg_th_us_user' not in data
-    data.calc_bg(bg.exp_fit, time_s=30, tail_min_us=300)
-    assert 'bg_auto_th_us0' not in data
-    assert 'bg_auto_F_bg' not in data
-    assert 'bg_th_us_user' in data
-    data.calc_bg(bg.exp_fit, time_s=30, tail_min_us='auto', F_bg=1.7)
+    
+    data.calc_bg(bg.exp_fit, time_s=30, tail_min_us='auto', F_bg=1.7,
+                 fit_allph=False)
+    streams = [s for s in data.ph_streams if s != Ph_sel('all')]
+    bg_t = [np.sum(data.bg[s][ich] for s in streams) for ich in range(data.nch)]
+    assert list_array_equal(data.bg[Ph_sel('all')], bg_t)
+
+
+def test_ph_streams(data):
+    sel = [Ph_sel('all'), Ph_sel(Dex='Dem'), Ph_sel(Dex='Aem')]
+    if data.ALEX:
+        sel.extend([Ph_sel(Aex='Aem'), Ph_sel(Aex='Dem')])
+    for s in sel:
+        assert s in data.ph_streams
+
 
 def test_bg_from(data):
     """Test the method .bg_from() for all the ph_sel combinations.
     """
     d = data
+    for sel in d.ph_streams:
+        bg = d.bg_from(ph_sel=sel)
+        assert list_array_equal(bg, d.bg[sel])
 
-    bg = d.bg_from(ph_sel=Ph_sel('all'))
-    assert list_array_equal(bg, d.bg)
-    bg = d.bg_from(ph_sel=Ph_sel(Dex='Dem'))
-    assert list_array_equal(bg, d.bg_dd)
-    bg = d.bg_from(ph_sel=Ph_sel(Dex='Aem'))
-    assert list_array_equal(bg, d.bg_ad)
+    if not data.ALEX:
+        assert list_array_equal(d.bg_from(Ph_sel('all')),
+                                d.bg_from(Ph_sel(Dex='DAem')))
+        return
 
-    if not d.ALEX:
-        bg = d.bg_from(ph_sel=Ph_sel(Dex='DAem'))
-        assert list_array_equal(bg, d.bg)
-    else:
-        bg = d.bg_from(ph_sel=Ph_sel(Aex='Dem'))
-        assert list_array_equal(bg, d.bg_da)
-        bg = d.bg_from(ph_sel=Ph_sel(Aex='Aem'))
-        assert list_array_equal(bg, d.bg_aa)
+    bg_dd = d.bg_from(ph_sel=Ph_sel(Dex='Dem'))
+    bg_ad = d.bg_from(ph_sel=Ph_sel(Dex='Aem'))
 
-        bg = d.bg_from(ph_sel=Ph_sel(Dex='DAem'))
-        bg_c = [bg1 + bg2 for bg1, bg2 in zip(d.bg_dd, d.bg_ad)]
-        assert list_array_equal(bg, bg_c)
+    bg = d.bg_from(ph_sel=Ph_sel(Dex='DAem'))
+    assert list_array_equal(bg, [b1 + b2 for b1, b2 in zip(bg_dd, bg_ad)])
 
-        bg = d.bg_from(ph_sel=Ph_sel(Aex='DAem'))
-        bg_c = [bg1 + bg2 for bg1, bg2 in zip(d.bg_da, d.bg_aa)]
-        assert list_array_equal(bg, bg_c)
+    bg_aa = d.bg_from(ph_sel=Ph_sel(Aex='Aem'))
+    bg_da = d.bg_from(ph_sel=Ph_sel(Aex='Dem'))
 
-        bg = d.bg_from(ph_sel=Ph_sel(Dex='Dem', Aex='Dem'))
-        bg_c = [bg1 + bg2 for bg1, bg2 in zip(d.bg_dd, d.bg_da)]
-        assert list_array_equal(bg, bg_c)
+    bg = d.bg_from(ph_sel=Ph_sel(Aex='DAem'))
+    assert list_array_equal(bg, [b1 + b2 for b1, b2 in zip(bg_aa, bg_da)])
 
-        bg = d.bg_from(ph_sel=Ph_sel(Dex='Aem', Aex='Aem'))
-        bg_c = [bg1 + bg2 for bg1, bg2 in zip(d.bg_ad, d.bg_aa)]
-        assert list_array_equal(bg, bg_c)
+    bg = d.bg_from(ph_sel=Ph_sel(Dex='Dem', Aex='Dem'))
+    assert list_array_equal(bg, [b1 + b2 for b1, b2 in zip(bg_dd, bg_da)])
 
-        bg = d.bg_from(ph_sel=Ph_sel(Dex='DAem', Aex='Aem'))
-        bg_c = [bg1 + bg2 + bg3
-                for bg1, bg2, bg3 in zip(d.bg_dd, d.bg_ad, d.bg_aa)]
-        assert list_array_equal(bg, bg_c)
+    bg = d.bg_from(ph_sel=Ph_sel(Dex='Aem', Aex='Aem'))
+    assert list_array_equal(bg, [b1 + b2 for b1, b2 in zip(bg_ad, bg_aa)])
+
+    bg = d.bg_from(ph_sel=Ph_sel(Dex='DAem'))
+    assert list_array_equal(bg, [b1 + b2 for b1, b2 in zip(bg_dd, bg_ad)])
+
+    bg = d.bg_from(ph_sel=Ph_sel(Dex='DAem', Aex='Aem'))
+    bg2 = [b1 + b2 + b3 for b1, b2, b3 in zip(bg_dd, bg_ad, bg_aa)]
+    assert list_array_equal(bg, bg2)
 
 
 def test_iter_ph_times(data):
@@ -207,21 +221,21 @@ def test_iter_ph_times(data):
 
     for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Dex='Dem'))):
         if d.ALEX:
-            assert (ph == d.ph_times_m[ich][d.D_em[ich]*d.D_ex[ich]]).all()
+            assert (ph == d.ph_times_m[ich][d.D_em[ich] * d.D_ex[ich]]).all()
         else:
             assert (ph == d.ph_times_m[ich][-d.A_em[ich]]).all()
 
     for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Dex='Aem'))):
         if d.ALEX:
-            assert (ph == d.ph_times_m[ich][d.A_em[ich]*d.D_ex[ich]]).all()
+            assert (ph == d.ph_times_m[ich][d.A_em[ich] * d.D_ex[ich]]).all()
         else:
             assert (ph == d.ph_times_m[ich][d.A_em[ich]]).all()
 
     if d.ALEX:
         for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Aex='Dem'))):
-            assert (ph == d.ph_times_m[ich][d.D_em[ich]*d.A_ex[ich]]).all()
+            assert (ph == d.ph_times_m[ich][d.D_em[ich] * d.A_ex[ich]]).all()
         for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Aex='Aem'))):
-            assert (ph == d.ph_times_m[ich][d.A_em[ich]*d.A_ex[ich]]).all()
+            assert (ph == d.ph_times_m[ich][d.A_em[ich] * d.A_ex[ich]]).all()
 
         for ich, ph in enumerate(d.iter_ph_times(Ph_sel(Dex='DAem'))):
             assert (ph == d.ph_times_m[ich][d.D_ex[ich]]).all()
@@ -234,8 +248,8 @@ def test_iter_ph_times(data):
             assert (ph == d.ph_times_m[ich][d.A_em[ich]]).all()
 
         for ich, ph in enumerate(d.iter_ph_times(
-                                    Ph_sel(Dex='DAem', Aex='Aem'))):
-            mask = d.D_ex[ich] + d.A_em[ich]*d.A_ex[ich]
+                Ph_sel(Dex='DAem', Aex='Aem'))):
+            mask = d.D_ex[ich] + d.A_em[ich] * d.A_ex[ich]
             assert (ph == d.ph_times_m[ich][mask]).all()
     else:
         assert list_array_equal(d.iter_ph_times(),
@@ -255,8 +269,8 @@ def test_iter_ph_times_period(data):
 
         ph_sel = Ph_sel(Dex='Dem')
         mask = d.get_ph_mask(ich=ich, ph_sel=ph_sel)
-        for period, ph_period in enumerate(d.iter_ph_times_period(ich=ich,
-                                                    ph_sel=ph_sel)):
+        for period, ph_period in enumerate(
+                d.iter_ph_times_period(ich=ich, ph_sel=ph_sel)):
             istart, iend = d.Lim[ich][period]
             ph_period_test = d.ph_times_m[ich][istart : iend + 1]
             ph_period_test = ph_period_test[mask[istart : iend + 1]]
@@ -289,20 +303,38 @@ def test_burst_search_with_no_bursts(data):
     # and in no bursts at all for the multi-spot measurements
     data.burst_search(m=10, F=600)
 
+def test_stale_fitter_after_burst_search(data):
+    """Test that E/S_fitter attributes are deleted on burst search."""
+    data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Dem'))
+    bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
+    if data.ALEX:
+        bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
+
+    data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Aem'))
+    assert not hasattr(data, 'E_fitter')
+    if data.ALEX:
+        assert not hasattr(data, 'S_fitter')
+
+    bplt.dplot(data, bplt.hist_fret)  # create E_fitter attribute
+    if data.ALEX:
+        bplt.dplot(data, bplt.hist_S)  # create S_fitter attribute
+
+    data.calc_fret()
+    assert not hasattr(data, 'E_fitter')
+    if data.ALEX:
+        assert not hasattr(data, 'S_fitter')
+
 def test_burst_search(data):
     """Smoke test and bg_bs check."""
-    data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Dem'))
-    assert list_equal(data.bg_bs, data.bg_dd)
-    data.burst_search(L=10, m=10, F=7, ph_sel=Ph_sel(Dex='Aem'))
-    assert list_equal(data.bg_bs, data.bg_ad)
+    streams = [Ph_sel(Dex='Dem'), Ph_sel(Dex='Aem')]
+    if data.ALEX:
+        streams.extend([Ph_sel(Dex='Aem', Aex='Aem'), Ph_sel(Dex='DAem')])
+    for sel in streams:
+        data.burst_search(L=10, m=10, F=7, ph_sel=sel)
+        assert list_equal(data.bg_bs, data.bg_from(sel))
 
     if data.ALEX:
-        data.burst_search(L=10, m=10, F=7,
-                          ph_sel=Ph_sel(Dex='Aem', Aex='Aem'))
-        bg_Aem = [b1 + b2 for b1, b2 in zip(data.bg_ad, data.bg_aa)]
-        assert list_equal(data.bg_bs, bg_Aem)
         data.burst_search(m=10, F=7, ph_sel=Ph_sel(Dex='DAem'), compact=True)
-
     data.burst_search(L=10, m=10, F=7)
 
 def test_burst_search_and_gate(data_1ch):
@@ -332,16 +364,26 @@ def test_burst_sizes(data):
     # Smoke test
     plain_sizes = data.burst_sizes()
     assert len(plain_sizes) == data.nch
-    # Test gamma and gamma1 arguments
-    bs1 = data.burst_sizes_ich(gamma=0.5)
-    bs2 = data.burst_sizes_ich(gamma1=0.5)
-    assert np.allclose(bs1, bs2/0.5)
+    # Test gamma and donor_ref arguments
+    bs1 = data.burst_sizes_ich(gamma=0.5, donor_ref=True)
+    bs2 = data.burst_sizes_ich(gamma=0.5, donor_ref=False)
+    assert np.allclose(bs1, bs2 / 0.5)
     # Test add_naa
     if data.ALEX:
         bs_no_naa = data.burst_sizes_ich(add_naa=False)
         bs_naa = data.burst_sizes_ich(add_naa=True)
         assert np.allclose(bs_no_naa + data.naa_, bs_naa)
 
+        # Test beta and donor_ref arguments with gamma=1
+        naa1 = data.get_naa_corrected(beta=0.8, donor_ref=True)
+        naa2 = data.get_naa_corrected(beta=0.8, donor_ref=False)
+        assert np.allclose(naa1, naa2)
+
+        # Test beta and donor_ref arguments with gamma=0.5
+        naa1 = data.get_naa_corrected(gamma=0.5, beta=0.8, donor_ref=True)
+        naa2 = data.get_naa_corrected(gamma=0.5, beta=0.8, donor_ref=False)
+        assert np.allclose(naa1 * 0.5, naa2)
+
 def test_leakage(data):
     """
     Test setting leakage before and after burst search
@@ -361,9 +403,11 @@ def test_gamma(data):
     """
     # burst search, then set gamma
     data.burst_search()
+    E0 = list(data.E)
     data.gamma = 0.5
     E1 = list(data.E)
-    # set leakage, then burst search
+    assert not list_array_equal(E0, E1)
+    # burst search after setting gamma
     data.burst_search()
     E2 = list(data.E)
     assert list_array_equal(E1, E2)
@@ -375,13 +419,31 @@ def test_dir_ex(data_1ch):
     data = data_1ch
     # burst search, then set dir_ex
     data.burst_search()
+    na0 = list(data.na)
     data.dir_ex = 0.05
     na1 = list(data.na)
-    # set leakage, then burst search
+    assert not list_array_equal(na0, na1)
+    # burst search after setting dir_ex
     data.burst_search()
     na2 = list(data.na)
     assert list_array_equal(na1, na2)
 
+def test_beta(data_1ch):
+    """
+    Test setting beta before and after burst search
+    """
+    data = data_1ch
+    # burst search, then set beta
+    data.burst_search()
+    S0 = list(data.S)
+    data.beta = 0.7
+    S1 = list(data.S)
+    assert not list_array_equal(S0, S1)
+    # burst search after setting beta
+    data.burst_search()
+    S2 = list(data.S)
+    assert list_array_equal(S1, S2)
+
 def test_bursts_interface(data):
     d = data
     for b in d.mburst:
@@ -637,16 +699,21 @@ def test_burst_data(data):
     """Smoke test for bext.burst_data()"""
     bext.burst_data(data, include_bg=True, include_ph_index=True)
 
+def test_print_burst_stats(data):
+    """Smoke test for burstlib.print_burst_stats()"""
+    bl.print_burst_stats(data)
+
 def test_expand(data):
     """Test method `expand()` for `Data()`."""
     d = data
     for ich, bursts in enumerate(d.mburst):
-        if bursts.num_bursts == 0: continue  # if no bursts skip this ch
+        if bursts.num_bursts == 0:
+            continue  # if no bursts skip this ch
         nd, na, bg_d, bg_a, width = d.expand(ich, width=True)
-        width2 = bursts.width*d.clk_p
+        width2 = bursts.width * d.clk_p
         period = d.bp[ich]
-        bg_d2 = d.bg_dd[ich][period] * width2
-        bg_a2 = d.bg_ad[ich][period] * width2
+        bg_d2 = d.bg_from(Ph_sel(Dex='Dem'))[ich][period] * width2
+        bg_a2 = d.bg_from(Ph_sel(Dex='Aem'))[ich][period] * width2
         assert (width == width2).all()
         assert (nd == d.nd[ich]).all() and (na == d.na[ich]).all()
         assert (bg_d == bg_d2).all() and (bg_a == bg_a2).all()
@@ -668,8 +735,8 @@ def test_burst_corrections(data):
         if d.ALEX:
             nda, naa = d.nda[ich], d.naa[ich]
             period = d.bp[ich]
-            bg_da = d.bg_da[ich][period]*width
-            bg_aa = d.bg_aa[ich][period]*width
+            bg_da = d.bg_from(Ph_sel(Aex='Dem'))[ich][period]*width
+            bg_aa = d.bg_from(Ph_sel(Aex='Aem'))[ich][period]*width
             burst_size_raw2 = (nd + na + bg_d + bg_a + lk*nd + nda + naa +
                                bg_da + bg_aa)
             assert np.allclose(burst_size_raw, burst_size_raw2)
@@ -702,6 +769,20 @@ def test_burst_search_consistency(data):
         start, stop, width = mb.start, mb.stop, mb.width
         assert np.all(width <= stop - start)
 
+def test_E_and_S_with_corrections(data):
+    d = data
+    gamma = 0.5
+    beta = 0.7
+    d.gamma = gamma
+    d.beta = beta
+    for i, (E, nd, na) in enumerate(zip(d.E, d.nd, d.na)):
+        assert (E == na / (nd * gamma + na)).all()
+        if d.ALEX:
+            naa = d.naa[i]
+            assert (d.S[i] == (gamma * nd + na) /
+                              (gamma * nd + na + naa / beta)).all()
+
+
 def test_burst_size_da(data):
     """Test that nd + na with no corrections is equal to b_size(mburst).
     """
